#version 100

precision mediump float;

uniform sampler2D texture;
varying vec2 texCoord;
uniform bool useSolidColor;
uniform vec4 solidColor;

uniform float opacity;

uniform float offsetTop;
uniform float offsetBottom;
uniform float offsetRight;
uniform float offsetLeft;

uniform sampler2D alphaMaskTexture;
uniform bool isMasked;
uniform int maskChannel;

void main() {
    // make sure outbound of texture pixels is transparent
    bool clearColor = texCoord.y > offsetTop || texCoord.y < offsetBottom || texCoord.x > offsetRight || texCoord.x < offsetLeft;
    vec4 texColor = texture2D(texture, texCoord) * vec4(!useSolidColor) + solidColor * vec4(useSolidColor);
    vec4 clearedColor = texColor * vec4(!clearColor);
    // Division by zero will not fail OpenGL but cause unspecified behaviour.
    // However, it is acceptable as the 4th component of the vector will be 0 anyway.
    vec4 fragColor = vec4(clearedColor.rgb / clearedColor.a, clearedColor.a * opacity);

    float opacityFactor = isMasked ? texture2D(alphaMaskTexture, texCoord)[maskChannel] : fragColor.a;
    fragColor.a = opacityFactor;

    gl_FragColor = fragColor;
}
