// from https://github.com/gl-transitions/gl-transitions

#version 100

#ifdef GL_ES
#ifdef GL_FRAGMENT_PRECISION_HIGH
precision highp float;
#else
precision mediump float;
#endif
#endif

varying vec2 texCoord;

uniform sampler2D texture;
uniform float opacity;
uniform sampler2D alphaMaskTexture;
uniform bool isMasked;
uniform int maskChannel;

uniform float offsetTop;
uniform float offsetBottom;
uniform float offsetRight;
uniform float offsetLeft;

void main() {
    // make sure outbound of texture pixels is transparent
    bool clearColor = texCoord.y > offsetTop || texCoord.y < offsetBottom || texCoord.x > offsetRight || texCoord.x < offsetLeft;
    vec4 color = texture2D(texture, texCoord);
    vec4 clearedColor = color * vec4(!clearColor);
    float opacityFactor;
    if (isMasked) {
        vec4 mask = texture2D(alphaMaskTexture, texCoord);
        opacityFactor = opacity * mask[maskChannel];
    } else {
        opacityFactor = opacity;
    }
    clearedColor.a *= opacityFactor;

    gl_FragColor = clearedColor;
}
